# Claude Code Instructions

## Plugin Development Workflow

When creating, modifying, or removing plugins:

1. **Always update the plugin documentation** in `docs/plugins.md` after any plugin changes
2. Ensure the documentation includes:
   - Plugin name and category (Development, Fun and entertainment, Utility, Security, Social Media)
   - Brief description of functionality
   - Usage instructions with examples
   - Any configuration requirements
3. **For plugins with configuration options:**
   - Set `ConfigRequired: true` in the plugin's BasePlugin struct
   - Add corresponding HTML form fields in `internal/admin/templates/channel_plugin_config.html`
   - Use conditional template logic: `{{else if eq .ChannelPlugin.PluginID "plugin.id"}}`
   - Include proper form labels, help text, and value binding

## Testing

Before committing plugin changes:

1. Check files are properly formatted: Run `make format`
2. Check code style and linting: Run `make lint`
3. Test the plugin functionality: Run `make test`
4. Verify documentation accuracy
5. Ensure all examples work as described
